@@ -3,22 +3,19 @@
 #' Analysis of variance (ANOVA) based on lower partial moment CDFs for multiple variables.  Returns a degree of certainty the difference in sample means is zero, not a p-value.
 #' @param control a numeric vector, matrix or data frame.
 #' @param treatment \code{NULL} (default) a numeric vector, matrix or data frame.
-#' @param binary logical; \code{TRUE} (default) Selects binary analysis between a control and treatment variable.
-#' @param confidence.interval numeric [0, 1]; The confidence interval surrounding the control mean when \code{(binary = TRUE)}.  Defaults to \code{(confidence.interval = 0.95)}.
+#' @param confidence.interval numeric [0, 1]; The confidence interval surrounding the \code{control} mean, defaults to \code{(confidence.interval = 0.95)}.
 #' @param tails options: ("Left", "Right", "Both").  \code{tails = "Both"}(Default) Selects the tail of the distribution to determine effect size.
-#' @param pairwise logical; \code{FALSE} (defualt) Returns pairwise certainty tests when set to \code{pairwise = TRUE}.
-#' @param plot logical; \code{TRUE} (default) Returns the boxplot of all variables along with grand mean identification.  When \code{(binary = TRUE)}, returns the boxplot of both variables along with grand mean identification and confidence interval thereof.
-#' @return For \code{(binary = FALSE)} returns the degree certainty the difference in sample means is zero [0, 1].
-#'
-#' For \code{(binary = TRUE)} returns:
+#' @param pairwise logical; \code{FALSE} (default) Returns pairwise certainty tests when set to \code{pairwise = TRUE}.
+#' @param plot logical; \code{TRUE} (default) Returns the boxplot of all variables along with grand mean identification and confidence interval thereof.
+#' @return Returns the following:
 #' \itemize{
-#' \item{\code{"Control Mean"}}
-#' \item{\code{"Treatment Mean"}}
-#' \item{\code{"Grand Mean"}}
-#' \item{\code{"Control CDF"}}
-#' \item{\code{"Treatment CDF"}}
-#' \item{\code{"Certainty"}} the certainty of the same population statistic
-#' \item{\code{"Lower Bound Effect"} and \code{"Upper Bound Effect"}} the effect size of the treatment for the specified confidence interval
+#' \item{\code{"Control Mean"}} \code{control} mean.
+#' \item{\code{"Treatment Mean"}} \code{treatment} mean.
+#' \item{\code{"Grand Mean"}} mean of means.
+#' \item{\code{"Control CDF"}} CDF of the \code{control} from the grand mean.
+#' \item{\code{"Treatment CDF"}} CDF of the \code{treatment} from the grand mean.
+#' \item{\code{"Certainty"}} the certainty of the same population statistic.
+#' \item{\code{"Lower Bound Effect"} and \code{"Upper Bound Effect"}} the effect size of the \code{treatment} for the specified confidence interval.
 #' }
 #'
 #' @author Fred Viole, OVVO Financial Systems
@@ -51,8 +48,7 @@ NNS.ANOVA <- function(control,
                      confidence.interval = 0.95,
                      tails = "Both",
                      pairwise = FALSE,
-                     plot = TRUE,
-                     binary = TRUE){
+                     plot = TRUE){
 
     tails <- tolower(tails)
     if(!any(tails%in%c("left","right","both"))){
